@@ -1,9 +1,9 @@
 #!/bin/bash
 __doc__="
-Remove intermediate 
+Remove intermediate clutter files  
 "
 find . -regex ".*\(__pycache__\|\.py[co]\)" -delete || find . -iname "*.pyc" -delete || find . -iname "*.pyo" -delete
 rm -rf build
 rm -rf htmlcov
-rm .coverage
-rm .coverage.*
+rm -f .coverage
+rm -f .coverage.*
