@@ -9,15 +9,31 @@ import ubelt as ub
 import pytest
 import os
 from ubelt import util_links
+import sys
+
+
+if sys.platform.startswith('win32'):
+    try:
+        import jaraco.windows.filesystem as jwfs
+    except ImportError:
+        jwfs = None
 
 
 def test_rel_dir_link():
+    """
+    xdoctest ~/code/ubelt/tests/test_links.py test_rel_dir_link
+    """
+    import pytest
+    import ubelt as ub
+    if ub.WIN32 and jwfs is None:
+        pytest.skip()  # hack for windows for now.
+
     dpath = ub.Path.appdir('ubelt/tests/test_links', 'test_rel_dir_link').ensuredir()
     ub.delete(dpath, verbose=2)
     ub.ensuredir(dpath, verbose=2)
 
-    real_dpath = join(ub.ensuredir((dpath, 'dir1')), 'real')
-    link_dpath = join(ub.ensuredir((dpath, 'dir2')), 'link')
+    real_dpath = join((dpath / 'dir1').ensuredir(), 'real')
+    link_dpath = join((dpath / 'dir2').ensuredir(), 'link')
     ub.ensuredir(real_dpath)
 
     orig = os.getcwd()
@@ -29,7 +45,11 @@ def test_rel_dir_link():
         # Note: on windows this is hacked.
         pointed = ub.util_links._readlink(link)
         resolved = os.path.realpath(ub.expandpath(join(dirname(link), pointed)))
-        assert os.path.realpath(ub.expandpath(real_dpath)) == resolved
+
+        final_real_dpath = os.path.realpath(ub.expandpath(real_dpath))
+        if final_real_dpath != resolved:
+            raise AssertionError(f'{final_real_dpath} != {resolved}')
+        # assert os.path.realpath(ub.expandpath(real_dpath)) == resolved
     except Exception:
         util_links._dirstats(dpath)
         util_links._dirstats(join(dpath, 'dir1'))
@@ -57,6 +77,10 @@ def test_rel_dir_link():
 
 
 def test_rel_file_link():
+    import pytest
+    import ubelt as ub
+    if ub.WIN32 and jwfs is None:
+        pytest.skip()  # hack for windows for now.
     dpath = ub.Path.appdir('ubelt/tests/test_links', 'test_rel_file_link').ensuredir()
     ub.delete(dpath, verbose=2)
     ub.ensuredir(dpath, verbose=2)
@@ -112,6 +136,10 @@ def test_delete_symlinks():
     CommandLine:
         python -m ubelt.tests.test_links test_delete_symlinks
     """
+    import pytest
+    import ubelt as ub
+    if ub.WIN32 and jwfs is None:
+        pytest.skip()  # hack for windows for now.
     # TODO: test that we handle broken links
     dpath = ub.Path.appdir('ubelt/tests/test_links', 'test_delete_links').ensuredir()
 
@@ -217,6 +245,10 @@ def test_delete_symlinks():
 
 
 def test_modify_directory_symlinks():
+    import pytest
+    import ubelt as ub
+    if ub.WIN32 and jwfs is None:
+        pytest.skip()  # hack for windows for now.
     dpath = ub.Path.appdir('ubelt/tests/test_links', 'test_modify_symlinks').ensuredir()
     ub.delete(dpath, verbose=2)
     ub.ensuredir(dpath, verbose=2)
@@ -276,6 +308,10 @@ def test_modify_file_symlinks():
     CommandLine:
         python -m ubelt.tests.test_links test_modify_symlinks
     """
+    import pytest
+    import ubelt as ub
+    if ub.WIN32 and jwfs is None:
+        pytest.skip()  # hack for windows for now.
     # TODO: test that we handle broken links
     dpath = ub.Path.appdir('ubelt/tests/test_links', 'test_modify_symlinks').ensuredir()
     happy_fpath = dpath / 'happy_fpath.txt'
@@ -299,6 +335,10 @@ def test_broken_link():
     CommandLine:
         python -m ubelt.tests.test_links test_broken_link
     """
+    import pytest
+    import ubelt as ub
+    if ub.WIN32 and jwfs is None:
+        pytest.skip()  # hack for windows for now.
     dpath = ub.Path.appdir('ubelt/tests/test_links', 'test_broken_link').ensuredir()
 
     ub.delete(dpath, verbose=2)
@@ -363,6 +403,10 @@ def test_overwrite_symlink():
     CommandLine:
         python ~/code/ubelt/tests/test_links.py test_overwrite_symlink
     """
+    import pytest
+    import ubelt as ub
+    if ub.WIN32 and jwfs is None:
+        pytest.skip()  # hack for windows for now.
 
     # TODO: test that we handle broken links
     dpath = ub.Path.appdir('ubelt/tests/test_links', 'test_overwrite_symlink').ensuredir()
@@ -432,6 +476,52 @@ def _force_junction(func):
     return _wrap
 
 
+def test_symlink_to_rel_symlink():
+    """
+    Test a case with a absolute link to a relative link to a real path.
+    """
+    import ubelt as ub
+    if ub.WIN32:
+        import pytest
+        pytest.skip('dont try on windows')
+
+    dpath = ub.Path.appdir('ubelt/tests/links/sym-to-relsym')
+    dpath.delete().ensuredir()
+
+    level1 = (dpath / 'level1').ensuredir()
+
+    real = dpath / 'real'
+    link1 = level1 / 'link1'
+
+    real.touch()
+
+    print('Should create')
+
+    # rel_link1_to_real = os.path.relpath(real, link1.parent)
+    # FIXME: This ub.symlink behavior seems broken
+
+    link1.symlink_to(os.path.relpath(real, link1.parent))
+    # ub.symlink(real_path=rel_link1_to_real, link_path=link1, verbose=3)
+
+    # ub.symlink(real_path=rel_link1_to_real, link_path=link2, verbose=3)
+    """
+    At this point we have:
+
+    ├── level1
+    │   ├── level2
+    │   │   └── link2 -> /home/joncrall/.cache/ubelt/tests/links/sym-to-relsym/level1/link1
+    │   └── link1 -> ../real
+    └── real
+    """
+    # _ = ub.cmd(f'tree {dpath}', verbose=3)
+
+    import pytest
+    with pytest.raises(FileExistsError):
+        ub.symlink(real_path=real, link_path=link1, verbose=3)
+
+    # ub.symlink(real_path=link1, link_path=link2, verbose=1)
+
+
 # class TestSymlinksForceJunction(object):
 fj_test_delete_symlinks = _force_junction(test_delete_symlinks)
 fj_test_modify_directory_symlinks = _force_junction(test_modify_directory_symlinks)
