@@ -1,6 +1,7 @@
 import ubelt as ub
 
-DEBUG_PATH = ub.Path.home().name == 'joncrall'
+DEBUG_PATH = 0
+# ub.Path.home().name == 'joncrall'
 
 
 def _demo_directory_structure():
@@ -112,6 +113,10 @@ def test_move_to_nested_non_existing():
     base = _demo_directory_structure()
     root = base / 'root'
 
+    import platform
+    if ub.WIN32 and platform.python_implementation() == 'PyPy':
+        ub.util_path._patch_win32_stats_on_pypy()
+
     if ub.LINUX:
         root2 = root.copy(root.augment(tail='2'))
         root3 = root.copy(root.augment(tail='3'))
@@ -397,8 +402,8 @@ def test_copy_dir_to_non_existing():
         # Our copy should behave like the linux copy
         case1 = _comparable_walk(base / 'our_copy')
         case2 = _comparable_walk(base / 'linux_copy')
-        print('case1 = {}'.format(ub.repr2(case1, nl=1)))
-        print('case2 = {}'.format(ub.repr2(case2, nl=1)))
+        print('case1 = {}'.format(ub.urepr(case1, nl=1)))
+        print('case2 = {}'.format(ub.urepr(case2, nl=1)))
         assert case1 == case2
 
     base.delete()
@@ -525,9 +530,9 @@ def test_copy_dir_to_existing_dir_withconflict():
         case1 = _comparable_walk(base / 'our_copy')
         case2 = _comparable_walk(base / 'linux_copy')
         case3 = _comparable_walk(base / 'linux_copyT')
-        print('case1 = {}'.format(ub.repr2(case1, nl=1)))
-        print('case3 = {}'.format(ub.repr2(case3, nl=1)))
-        print('case2 = {}'.format(ub.repr2(case2, nl=1)))
+        print('case1 = {}'.format(ub.urepr(case1, nl=1)))
+        print('case3 = {}'.format(ub.urepr(case3, nl=1)))
+        print('case2 = {}'.format(ub.urepr(case2, nl=1)))
         assert case1 == case3
         assert case1 != case2
     base.delete()
